# pyFEDIC : Digital Image (2D/3D) Correlation Software

pyFEDIC is a DIC software using global approach with finite element shape functions to describe the displacement field. It allows to perform 2D DIC and 3D DIC also called DVC (V stand for volume).

This software is a pure python library and offer a simple command line to run analysis with a few parameters as input.

It can be directly installed using pip:

```console
$ pip install pyfedic
```

For more information, visit https://sourcesup.renater.fr/www/pyfedic/html/index.html


[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.8298429.svg)](https://doi.org/10.5281/zenodo.8298429)

